"use strict";

exports.__esModule = true;
exports.default = void 0;
var _rax = require("rax");
var _qr = _interopRequireDefault(require("qr.js"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }
function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function (o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }
var ErrorCorrectLevelMap = /*#__PURE__*/function (ErrorCorrectLevelMap) {
  ErrorCorrectLevelMap[ErrorCorrectLevelMap["L"] = 1] = "L";
  ErrorCorrectLevelMap[ErrorCorrectLevelMap["M"] = 0] = "M";
  ErrorCorrectLevelMap[ErrorCorrectLevelMap["Q"] = 3] = "Q";
  ErrorCorrectLevelMap[ErrorCorrectLevelMap["H"] = 2] = "H";
  return ErrorCorrectLevelMap;
}(ErrorCorrectLevelMap || {});
var styles = {
  qrCode: {
    width: 300,
    height: 300
  }
};
var QRCode = /*#__PURE__*/function (_Component) {
  _inheritsLoose(QRCode, _Component);
  function QRCode(props) {
    var _this = _Component.call(this, props) || this;
    _this.width = 0;
    _this.height = 0;
    _this.canvas = void 0;
    _this.state = {
      canvasWidth: 0,
      canvasHeight: 0
    };
    _this.drawCode = function (data, options) {
      var _this$canvas$current;
      if (data === '') {
        return;
      }
      var opt = Object.assign(options, {
        errorCorrectLevel: ErrorCorrectLevelMap[options.errorCorrectLevel || 'H']
      });
      var codeData = (0, _qr.default)(data, opt);
      var _options$fillColor = options.fillColor,
        fillColor = _options$fillColor === void 0 ? '#000000' : _options$fillColor,
        _options$blankColor = options.blankColor,
        blankColor = _options$blankColor === void 0 ? '#ffffff' : _options$blankColor;
      var cells = codeData.modules;
      var tileWidth = _this.state.canvasWidth / cells.length;
      var tileHeight = _this.state.canvasHeight / cells.length;
      var ctx = (_this$canvas$current = _this.canvas.current) == null ? void 0 : _this$canvas$current.getContext('2d');
      ctx.clearRect(0, 0, tileWidth, tileHeight);
      for (var r = 0; r < cells.length; ++r) {
        var row = cells[r];
        for (var c = 0; c < row.length; ++c) {
          ctx.fillStyle = row[c] ? fillColor : blankColor;
          var w = _this.getSideLenOfRect(c, tileWidth);
          var h = _this.getSideLenOfRect(r, tileHeight);
          ctx.fillRect(Math.round(c * tileWidth), Math.round(r * tileHeight), w, h);
        }
      }
    };
    var _props$style = props.style,
      style = _props$style === void 0 ? {} : _props$style;
    var _style$width = style.width,
      width = _style$width === void 0 ? 300 : _style$width,
      _style$height = style.height,
      height = _style$height === void 0 ? 300 : _style$height;
    _this.width = width;
    _this.height = height;
    _this.canvas = (0, _rax.createRef)();
    return _this;
  }
  var _proto = QRCode.prototype;
  _proto.initCanvasLayoutAndDraw = function initCanvasLayoutAndDraw(data, options) {
    var _this2 = this;
    var canvasNode = this.canvas.current;
    if (!canvasNode) return;
    if (canvasNode.width !== 0 && canvasNode.height !== 0 && canvasNode.width === this.state.canvasWidth && canvasNode.height === this.state.canvasHeight) {
      this.drawCode(data, options);
    } else {
      var _canvasNode$getBoundi = canvasNode.getBoundingClientRect(),
        width = _canvasNode$getBoundi.width,
        height = _canvasNode$getBoundi.height;
      this.setState({
        canvasWidth: width,
        canvasHeight: height
      }, function () {
        console.log(_this2.state);
        _this2.drawCode(data, options);
      });
    }
  };
  _proto.componentDidMount = function componentDidMount() {
    var _this$props = this.props,
      _this$props$data = _this$props.data,
      data = _this$props$data === void 0 ? '' : _this$props$data,
      _this$props$options = _this$props.options,
      options = _this$props$options === void 0 ? {} : _this$props$options;
    this.initCanvasLayoutAndDraw(data, options);
  };
  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    var data = nextProps.data,
      _nextProps$options = nextProps.options,
      options = _nextProps$options === void 0 ? {} : _nextProps$options;
    if (data !== this.props.data) {
      this.initCanvasLayoutAndDraw(data, options);
    }
  };
  _proto.getSideLenOfRect = function getSideLenOfRect(index, tileLen) {
    return Math.ceil((index + 1) * tileLen) - Math.floor(index * tileLen);
  };
  _proto.render = function render() {
    var style = this.props.style;
    return (0, _rax.createElement)("canvas", {
      width: this.state.canvasWidth,
      height: this.state.canvasHeight,
      style: _extends({}, styles.qrCode, style),
      ref: this.canvas
    });
  };
  return QRCode;
}(_rax.Component);
var _default = QRCode;
exports.default = _default;